<?php
/**
 * fa language file
 *
 * This file was initially built by fetching translations from other
 * Wiki projects. See the @url lines below. Additional translations
 * and fixes where done for DokuWiki by the people mentioned in the
 * lines starting with @author
 *
 * @url http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/languages/messages/MessagesFa.php?view=co
 * @author behrad eslamifar <behrad_es@yahoo.com)
 * @author Mohsen Firoozmandan <info@mambolearn.com>
 * @author Omid Mottaghi <omidmr@gmail.com>
 * @author Mohammad Reza Shoaei <shoaei@gmail.com>
 * @author Milad DZand <M.DastanZand@gmail.com>
 * @author AmirH Hassaneini <mytechmix@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'rtl';
$lang['doublequoteopening']    = '«';
$lang['doublequoteclosing']    = '»';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'ویرایش این صفحه';
$lang['btn_source']            = 'نمایش مبدا';
$lang['btn_show']              = 'نمایش صفحه';
$lang['btn_create']            = 'ساخت این صفحه';
$lang['btn_search']            = 'جستجو';
$lang['btn_save']              = 'ذخیره';
$lang['btn_preview']           = 'پیش‌نمایش';
$lang['btn_top']               = 'برگشت به بالا';
$lang['btn_newer']             = 'نتایج بیشتر »';
$lang['btn_older']             = '« نتایج کمتر';
$lang['btn_revs']              = 'نگارش‌های پیشین';
$lang['btn_recent']            = 'تغییرات اخیر';
$lang['btn_upload']            = 'ارسال';
$lang['btn_cancel']            = 'لغو';
$lang['btn_index']             = 'فهرست';
$lang['btn_secedit']           = 'ویرایش';
$lang['btn_login']             = 'ورود به سیستم';
$lang['btn_logout']            = 'خروج از سیستم';
$lang['btn_admin']             = 'مدیر';
$lang['btn_update']            = 'به روز رسانی';
$lang['btn_delete']            = 'حذف';
$lang['btn_back']              = 'عقب';
$lang['btn_backlink']          = 'پیوندهای به این صفحه';
$lang['btn_backtomedia']       = 'بازگشت به انتخاب فایل';
$lang['btn_subscribe']         = 'عضویت در تغییرات صفحه';
$lang['btn_profile']           = 'به روز رسانی پروفایل';
$lang['btn_reset']             = 'بازنشاندن';
$lang['btn_resendpwd']         = 'تعیین کلمه عبور جدید';
$lang['btn_draft']             = 'ویرایش پیش‌نویس';
$lang['btn_recover']           = 'بازیابی پیش‌نویس';
$lang['btn_draftdel']          = 'حذف پیش‌نویس';
$lang['btn_revert']            = 'بازیابی';
$lang['btn_register']          = 'یک حساب جدید بسازید';
$lang['btn_apply']             = 'اعمال کن';
$lang['btn_media']             = 'مدیریت محتوای چند رسانه ای';
$lang['loggedinas']            = 'به عنوان کاربر روبرو وارد شده‌اید:';
$lang['user']                  = 'نام کاربری:';
$lang['pass']                  = 'گذرواژه‌ی شما';
$lang['newpass']               = 'گذروازه‌ی جدید';
$lang['oldpass']               = 'گذرواژه‌ی پیشین';
$lang['passchk']               = 'گذرواژه را دوباره وارد کنید';
$lang['remember']              = 'گذرواژه را به یاد بسپار.';
$lang['fullname']              = '*نام واقعی شما';
$lang['email']                 = 'ایمیل شما*';
$lang['profile']               = 'پروفایل کاربر';
$lang['badlogin']              = 'خطا در ورود به سیستم';
$lang['minoredit']             = 'این ویرایش خُرد است';
$lang['draftdate']             = 'ذخیره خودکار پیش‌نویس';
$lang['nosecedit']             = 'این صفحه در این میان تغییر کرده است، اطلاعات بخش قدیمی شده است، در عوض محتوای کل نمایش داده می‌شود.';
$lang['regmissing']            = 'متاسفم، شما باید همه قسمت‌ها را پر کنید.';
$lang['reguexists']            = 'نام کاربری‌ای که وارد کردید قبلن استفاده شده است. خواهشمندیم یک نام دیگر انتخاب کنید.';
$lang['regsuccess']            = 'کاربر ساخته شد و گذرواژه به صورت ایمیل ارسال گردید.';
$lang['regsuccess2']           = 'حساب ایجاد شد.';
$lang['regmailfail']           = 'مشکلی در ارسال ایمیل پیش آمده است، با مدیر تماس بگیرید!';
$lang['regbadmail']            = 'نشانی واردشده‌ی ایمیل قابل‌قبول نیست، چرا که دارای ساختار نامعتبری است. خواهشمندیم نشانی‌ای با ساختار صحیح وارد کنید و یا بخش مربوط را خالی بگذارید.';
$lang['regbadpass']            = 'گذرواژه‌هایی که وارد کردید یکسان نیستند.';
$lang['regpwmail']             = 'گذرواژه‌ی DokuWiki شما';
$lang['reghere']               = 'شما هنوز حسابی در اینجا ندارید؟ یکی ایجاد کنید';
$lang['profna']                = 'این ویکی اجازه ویرایش پروفایل را نمی‌دهد';
$lang['profnochange']          = 'تغییری صورت نگرفت';
$lang['profnoempty']           = 'نام و آدرس ایمیل باید پر شود';
$lang['profchanged']           = 'پروفایل کاربر با موفقیت به روز شد';
$lang['pwdforget']             = 'گذرواژه‌ی خود را فراموش کرده‌اید؟ جدید دریافت کنید';
$lang['resendna']              = 'این ویکی ارسال مجدد گذرواژه را پشتیبانی نمی‌کند';
$lang['resendpwd']             = 'تعیین کلمه عبور جدید برای ';
$lang['resendpwdmissing']      = 'متاسفم، شما باید تمام قسمت‌ها را پر کنید';
$lang['resendpwdnouser']       = 'متاسفم، ما نتوانستیم این نام کاربری را در بانک خود پیدا کنیم';
$lang['resendpwdbadauth']      = 'متاسفم، کد شناسایی معتبر نیست. از صحت لینک تاییدیه اطمینان حاصل کنید.';
$lang['resendpwdconfirm']      = 'یک ایمیل تاییدیه‌ی آدرس به آدرس مورنظر ارسال شد. قبل از اینکه نامه‌ی دیگری قابل ارسال به این آدرس باشد، باید دستوراتی که در آن نامه آمده است را جهت تایید این مساله که این آدرس متعلق به شماست، اجرا کنید.';
$lang['resendpwdsuccess']      = 'گذرواژه‌ی جدید شما توسط ایمیل ارسال شد';
$lang['license']               = 'به جز مواردی که ذکر می‌شود، مابقی محتویات ویکی تحت مجوز زیر می‌باشند:';
$lang['licenseok']             = 'توجه: با ویرایش این صفحه، شما مجوز زیر را تایید می‌کنید:';
$lang['searchmedia']           = 'نام فایل برای جستجو:';
$lang['searchmedia_in']        = 'جستجو در %s';
$lang['txt_upload']            = 'فایل را برای ارسال انتخاب کنید';
$lang['txt_filename']          = 'ارسال به صورت (اختیاری)';
$lang['txt_overwrt']           = 'بر روی فایل موجود بنویس';
$lang['maxuploadsize']         = 'حداکثر %s برای هر فایل مجاز است.';
$lang['lockedby']              = 'در حال حاضر قفل شده است';
$lang['lockexpire']            = 'قفل منقضی شده است';
$lang['js']['willexpire']      = 'حالت قفل شما مدتی است منقضی شده است \n برای جلوگیری از تداخل دکمه‌ی پیش‌نمایش را برای صفر شدن ساعت قفل بزنید.';
$lang['js']['notsavedyet']     = 'تغییرات ذخیره شده از بین خواهد رفت.
 می‌خواهید ادامه دهید؟';
$lang['js']['searchmedia']     = 'جستجو برای فایل';
$lang['js']['keepopen']        = 'پنجره را ر زمان انتخاب باز نگه‌دار';
$lang['js']['hidedetails']     = 'پتهان کردن جزییات';
$lang['js']['mediatitle']      = 'تنظیمات پیوند';
$lang['js']['mediadisplay']    = 'نوع پیوند';
$lang['js']['mediaalign']      = 'هم‌ترازی';
$lang['js']['mediasize']       = 'اندازه تصویر';
$lang['js']['mediatarget']     = 'هدف پیوند';
$lang['js']['mediaclose']      = 'بستن';
$lang['js']['mediainsert']     = 'درج کردن';
$lang['js']['mediadisplayimg'] = 'نمایش تصویر';
$lang['js']['mediadisplaylnk'] = 'فقط پیوند را نمایش بده.';
$lang['js']['mediasmall']      = 'نگارش کوچک';
$lang['js']['mediamedium']     = 'نگارش متوسط';
$lang['js']['medialarge']      = 'نگارش بزرگ';
$lang['js']['mediaoriginal']   = 'نگارش اصلی';
$lang['js']['medialnk']        = 'پیوند به صفحه‌ی جزییات';
$lang['js']['mediadirect']     = 'پیوند مستقیم به اصلی';
$lang['js']['medianolnk']      = 'بدون پیوند';
$lang['js']['medianolink']     = 'تصویر را پیوند نکن';
$lang['js']['medialeft']       = 'تصویر را با چپ هم‌تراز کن.';
$lang['js']['mediaright']      = 'تصویر را با راست هم‌تراز کن.';
$lang['js']['mediacenter']     = 'تصویر را با وسط هم‌تراز کن.';
$lang['js']['medianoalign']    = 'هم‌تراز نکن.';
$lang['js']['nosmblinks']      = 'پیوند به Windows share فقط در اینترنت‌اکسپلورر قابل استفاده است.
شما می‌توانید پیوند‌ها رو کپی کنید.';
$lang['js']['linkwiz']         = 'ویزارد پیوند';
$lang['js']['linkto']          = 'پیوند به:';
$lang['js']['del_confirm']     = 'واقعن تصمیم به حذف این موارد دارید؟';
$lang['js']['restore_confirm'] = 'آیا مطمئن هستید که می خواهید این نسخه را بازیابی کنید؟';
$lang['js']['media_diff']      = 'تفاوت ها را ببینید : ';
$lang['js']['media_diff_both'] = 'پهلو به پهلو';
$lang['js']['media_diff_opacity'] = 'درخشش از';
$lang['js']['media_diff_portions'] = 'کش رفتن';
$lang['js']['media_select']    = 'انتخاب فایل -یا فایلها- ...';
$lang['js']['media_upload_btn'] = 'آپلود';
$lang['js']['media_done_btn']  = 'انجام شد';
$lang['js']['media_drop']      = 'فایل ها را در اینجا قرار دهید تا آپلود شود';
$lang['js']['media_cancel']    = 'حذف';
$lang['js']['media_overwrt']   = 'جاینوشت فایل های موجود';
$lang['rssfailed']             = 'بروز خطا در هنگام واکشی';
$lang['nothingfound']          = 'چیزی پیدا نشد';
$lang['mediaselect']           = 'فایل‌ها';
$lang['fileupload']            = 'ارسال پرونده';
$lang['uploadsucc']            = 'ارسال با موفقیت انجام شد';
$lang['uploadfail']            = 'خطا در ارسال';
$lang['uploadwrong']           = 'ارسال متوقف شد. این توسعه‌ی فایل ممنوع می‌باشد.';
$lang['uploadexist']           = 'این فابل وجود دارد. عملی انجام نشد.';
$lang['uploadbadcontent']      = 'محتوای فایل ارسال شده با توسعه‌ی %s متناقض است.';
$lang['uploadspam']            = 'فایل ارسال شده توسط لیست سیاه اسپم‌ها مسدود شده است.';
$lang['uploadxss']             = 'این صفحه حاوی اسکریپت یا کد اچ‌تی‌ام‌ال است که ممکن است به نادرست توسط مرورگر وب تفسیر شود.';
$lang['uploadsize']            = 'فایل ارسال شده سنگین است. (بیشینه، %s)';
$lang['deletesucc']            = 'فایل «%s» حذف شد.';
$lang['deletefail']            = '«%s» حذف نمی‌شود، دسترسی‌ها را بررسی کنید.';
$lang['mediainuse']            = 'فایل «%s» حذف نمی‌شود، چون هنوز در حال استفاده است.';
$lang['namespaces']            = 'فضای‌نام';
$lang['mediafiles']            = 'فایل‌های موجود در';
$lang['accessdenied']          = 'شما اجازه‌ی مشاهده‌ی این صفحه را ندارید.';
$lang['mediausage']            = 'برای ارجاع دادن به فایل از نگارش زیر استفاده کنید.';
$lang['mediaview']             = 'مشاهده‌ی فایل اصلی';
$lang['mediaroot']             = 'ریشه';
$lang['mediaupload']           = 'ارسال فایل به فضای‌نام کنونی. برای ایجاد زیرفضای‌نام‌ها، نام‌های آن‌ها را به عنوان پیشوندهایی که با دونقطه «:» جدا شده‌اند به نام فایل، در قسمت «ارسال به صورت» اضافه کنید.';
$lang['mediaextchange']        = 'توسعه‌ی فایل از %s به %s تغییر داده شد.';
$lang['reference']             = 'ارجاع‌های';
$lang['ref_inuse']             = 'این فایل نمی‌تواند حذف شود، زیرا هم‌چنان در این صفحه استفاده شده است:';
$lang['ref_hidden']            = 'تعدادی مرجع در صفحاتی که شما دسترسی خواندن ندارید وجود دارد.';
$lang['hits']                  = 'بازدید';
$lang['quickhits']             = 'جور کردن نام صفحات';
$lang['toc']                   = 'فهرست مندرجات';
$lang['current']               = 'فعلی';
$lang['yours']                 = 'نسخه‌ی شما';
$lang['diff']                  = 'تفاوت‌ها را با نگارش کنونی نمایش بده.';
$lang['diff2']                 = 'تفاوت‌ها را با نگارش انتخابی نمایش بده.';
$lang['difflink']              = 'پیوند به صفحه‌ی تفاوت‌ها';
$lang['diff_type']             = 'مشاهده تغییرات:';
$lang['diff_inline']           = 'خطی';
$lang['diff_side']             = 'کلی';
$lang['line']                  = 'خط';
$lang['breadcrumb']            = 'ردپا';
$lang['youarehere']            = 'محل شما';
$lang['lastmod']               = 'آخرین ویرایش';
$lang['by']                    = 'توسط';
$lang['deleted']               = 'حذف شد';
$lang['created']               = 'ایجاد شد';
$lang['restored']              = 'یک نگارش پیشین واگردانی شد. (%s)';
$lang['external_edit']         = 'ویرایش خارجی';
$lang['summary']               = 'پیش‌نمایش';
$lang['noflash']               = 'برای نمایش محتویات <a href="http://www.adobe.com/products/flashplayer/">افزونه‌ی فلش</a> مورد نیاز است.';
$lang['download']              = 'دیافت فایل منقطع گردید';
$lang['tools']                 = 'ابزار';
$lang['user_tools']            = 'ابزار کاربر';
$lang['site_tools']            = 'ابزار سایت';
$lang['page_tools']            = 'ابزار صفحه';
$lang['skip_to_content']       = 'پرش به محتوا';
$lang['sidebar']               = 'نوار کناری';
$lang['mail_newpage']          = 'صفحه اضافه شد:';
$lang['mail_changed']          = 'صفحه تغییر داده شد:';
$lang['mail_subscribe_list']   = 'صفحات تغییر داده شده در فضای‌نام';
$lang['mail_new_user']         = 'کاربر جدید:';
$lang['mail_upload']           = 'فایل ارسال شده:';
$lang['changes_type']          = 'دیدن تغییرات';
$lang['pages_changes']         = 'صفحات';
$lang['media_changes']         = 'فایلهای چند رسانه ای';
$lang['both_changes']          = 'صفحات و فایل های چند رسانه ای هر دو';
$lang['qb_bold']               = 'متن پُررنگ';
$lang['qb_italic']             = 'متن ایتالیک';
$lang['qb_underl']             = 'متن زیرخط‌دار';
$lang['qb_code']               = 'کد';
$lang['qb_strike']             = 'متن وسط‌خط‌دار';
$lang['qb_h1']                 = 'عنوان سطح ۱';
$lang['qb_h2']                 = 'عنوان سطح ۲';
$lang['qb_h3']                 = 'عنوان سطح ۳';
$lang['qb_h4']                 = 'عنوان سطح ۴';
$lang['qb_h5']                 = 'عنوان سطح ۵';
$lang['qb_h']                  = 'تیتر';
$lang['qb_hs']                 = 'تیتر مورد نظر را انتخاب نمایید';
$lang['qb_hplus']              = 'تیتر بالاتر';
$lang['qb_hminus']             = 'تیتر پایین تر';
$lang['qb_hequal']             = 'تیتر در یک سطح';
$lang['qb_link']               = 'پیوند داخلی';
$lang['qb_extlink']            = 'پیوند به بیرون (پیشوند http:// را فراموش نکنید)';
$lang['qb_hr']                 = 'خط افقی';
$lang['qb_ol']                 = 'لیست‌های مرتب';
$lang['qb_ul']                 = 'لیست‌های بدون ترتیب';
$lang['qb_media']              = 'افزودن تصویر و فایل';
$lang['qb_sig']                = 'افزودن امضا';
$lang['qb_smileys']            = 'شکلک';
$lang['qb_chars']              = 'حروف ویژه';
$lang['upperns']               = 'پرش به فضای‌نام بالا';
$lang['admin_register']        = 'یک حساب جدید بسازید';
$lang['metaedit']              = 'ویرایش داده‌های متا';
$lang['metasaveerr']           = 'نوشتن داده‌نما با مشکل مواجه شد';
$lang['metasaveok']            = 'داده‌نما ذخیره شد';
$lang['img_backto']            = 'بازگشت به ';
$lang['img_title']             = 'عنوان تصویر';
$lang['img_caption']           = 'عنوان';
$lang['img_date']              = 'تاریخ';
$lang['img_fname']             = 'نام فایل';
$lang['img_fsize']             = 'اندازه';
$lang['img_artist']            = 'عکاس/هنرمند';
$lang['img_copyr']             = 'دارنده‌ی حق تکثیر';
$lang['img_format']            = 'فرمت';
$lang['img_camera']            = 'دوربین';
$lang['img_keywords']          = 'واژه‌های کلیدی';
$lang['img_width']             = 'عرض';
$lang['img_height']            = 'ارتفاع';
$lang['img_manager']           = 'دیدن در مدیریت محتوای چند رسانه ای';
$lang['subscr_subscribe_success'] = '%s به لیست آبونه %s افزوده شد';
$lang['subscr_subscribe_error'] = 'اشکال در افزودن %s به لیست آبونه %s';
$lang['subscr_subscribe_noaddress'] = 'هیچ آدرسی برای این عضویت اضافه نشده است، شما نمی‌توانید به لیست آبونه اضافه شوید';
$lang['subscr_unsubscribe_success'] = '%s از لیست آبونه %s پاک شد';
$lang['subscr_unsubscribe_error'] = 'اشکال در پاک کردن %s از لیست آبونه %s';
$lang['subscr_already_subscribed'] = '%s پیش‌تر در %s آبونه شده است';
$lang['subscr_not_subscribed'] = '%s در %s آبونه نشده است';
$lang['subscr_m_not_subscribed'] = 'شما در این صفحه یا فضای‌نام آبونه نشده‌اید';
$lang['subscr_m_new_header']   = 'افزودن آبونه';
$lang['subscr_m_current_header'] = 'آبونه‌های کنونی';
$lang['subscr_m_unsubscribe']  = 'لغو آبونه';
$lang['subscr_m_subscribe']    = 'آبونه شدن';
$lang['subscr_m_receive']      = 'دریافت کردن';
$lang['subscr_style_every']    = 'ارسال رای‌نامه در تمامی تغییرات';
$lang['authmodfailed']         = 'اشکال در نوع معتبرسازی کاربران، مدیر ویکی را باخبر سازید.';
$lang['authtempfail']          = 'معتبرسازی کابران موقتن مسدود می‌باشد. اگر این حالت پایدار بود، مدیر ویکی را باخبر سازید.';
$lang['authpwdexpire']         = 'کلمه عبور شما در %d روز منقضی خواهد شد ، شما باید آن را زود تغییر دهید';
$lang['i_chooselang']          = 'انتخاب زبان';
$lang['i_installer']           = 'نصب کننده‌ی Dokuwiki';
$lang['i_wikiname']            = 'نام ویکی';
$lang['i_enableacl']           = 'فعال بودن کنترل دسترسی‌ها (توصیه شده)';
$lang['i_superuser']           = 'کاربر اصلی';
$lang['i_problems']            = 'نصب کننده با مشکلات زیر مواجه شد. در صورت رفع این مشکلات، امکان ادامه نصب خواهد بود.';
$lang['i_modified']            = 'به دلایل امنیتی، این اسکریپت فقط با نصب تازه و بدون تغییر DokuWiki کار خواهد کرد.شما باید دوباره فایل فشرده را باز کنید <a href="http://dokuwiki.org/install">راهنمای نصب DokuWiki</a> را بررسی کنید.';
$lang['i_funcna']              = 'تابع <code>%s</code> در PHP موجود نیست. ممکن است شرکت خدمات وب شما آن را مسدود کرده باشد.';
$lang['i_phpver']              = 'نگارش پی‌اچ‌پی <code>%s</code> پایین‌تر از نگارش مورد نیاز، یعنی <code>%s</code> می‌باشد. خواهشمندیم به روز رسانی کنید.';
$lang['i_permfail']            = 'شاخه‌ی <code>%s</code> قابلیت نوشتن ندارد. شما باید دسترسی‌های این شاخه را تنظیم کنید!';
$lang['i_confexists']          = '<code>%s</code> پیش‌تر موجود است';
$lang['i_writeerr']            = 'توانایی ایجاد <code>%s</code> نیست. شما باید دسترسی‌های شاخه یا فایل را بررسی کنید و فایل را به طور دستی ایجاد کنید.';
$lang['i_badhash']             = 'فایل dokuwiki.php غیرقابل تشخیص بوده یا تغییر کرده است (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - غیرقانونی و یا مقادیر تهی';
$lang['i_success']             = 'تنظیمات با موفقیت به پایان رسید. بهتر است فایل install.php رو حذف کنید. برای ادامه <a href="doku.php?id=wiki:welcome">این‌جا</a> کلیک کنید.';
$lang['i_failure']             = 'مشکلاتی در زمان نوشتن فایل تنظیمات پیش آمده است. شما باید این مشکلات را پیش از استفاده از <a href="doku.php?id=wiki:welcome">DokuWiki</a> برطرف کنید.';
$lang['i_policy']              = 'کنترل دسترسی‌های اولیه';
$lang['i_pol0']                = 'ویکی باز (همه می‌توانند بخوانند، بنویسند و فایل ارسال کنند)';
$lang['i_pol1']                = 'ویکی عمومی (همه می‌توانند بخوانند، کاربران ثبت شده می‌توانند بنویسند و فایل ارسال کنند)';
$lang['i_pol2']                = 'ویکی بسته (فقط کاربران ثبت شده می‌توانند بخوانند، بنویسند و فایل ارسال کنند)';
$lang['i_retry']               = 'تلاش مجدد';
$lang['i_license']             = 'لطفن مجوز این محتوا را وارد کنید:';
$lang['recent_global']         = 'شما هم‌اکنون تغییرات فضای‌نام <b>%s</b> را مشاهده می‌کنید. شما هم‌چنین می‌توانید <a href="%s">تغییرات اخیر در کل ویکی را مشاهده نمایید</a>.';
$lang['years']                 = '%d سال پیش';
$lang['months']                = '%d ماه پیش';
$lang['weeks']                 = '%d هفته‌ی پیش';
$lang['days']                  = '%d روز پیش';
$lang['hours']                 = '%d ساعت پیش';
$lang['minutes']               = '%d دقیقه‌ی پیش';
$lang['seconds']               = '%d ثانیه‌ی پیش';
$lang['wordblock']             = 'تغییرات شما به دلیل داشتن محتوای مشکوک (مثل اسپم) ذخیره نشد.';
$lang['media_uploadtab']       = 'آپلود';
$lang['media_searchtab']       = 'جستجو';
$lang['media_file']            = 'فایل';
$lang['media_viewtab']         = 'دیدن';
$lang['media_edittab']         = 'ویرایش';
$lang['media_historytab']      = 'تاریخچه';
$lang['media_list_thumbs']     = 'ریز عکسها';
$lang['media_list_rows']       = 'سطرها';
$lang['media_sort_name']       = 'ستون ها';
$lang['media_sort_date']       = 'تاریخ';
$lang['media_namespaces']      = 'انتخاب فضای نام';
$lang['media_files']           = 'فایل در %s';
$lang['media_upload']          = 'آپلود به %s';
$lang['media_search']          = 'جستجو در %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s در %s';
$lang['media_edit']            = '%s ویرایش';
$lang['media_history']         = 'تاریخچه %s';
$lang['media_meta_edited']     = 'فرا داده ها ویرایش شدند.';
$lang['media_perm_read']       = 'متاسفانه ، شما حق خواندن این فایل ها را ندارید.';
$lang['media_perm_upload']     = 'متاسفانه ، شما حق آپلود این فایل ها را ندارید.';
$lang['media_update']          = 'آپلود نسخه جدید';
$lang['media_restore']         = 'بازیابی این نسخه';
